@@ -764,7 +764,7 @@ directory_menu_plugin_menu_unload (GtkWidget *menu)
 {
   /* delay destruction so we can handle the activate event first */
   gtk_container_foreach (GTK_CONTAINER (menu),
-     (GtkCallback) panel_utils_destroy_later, NULL);
+     (GtkCallback) (void (*)(void)) panel_utils_destroy_later, NULL);
 }
 
 
@@ -805,7 +805,7 @@ G_GNUC_END_IGNORE_DEPRECATIONS
   gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
   g_signal_connect_data (G_OBJECT (mi), "activate",
       G_CALLBACK (directory_menu_plugin_menu_open_folder),
-      g_object_ref (dir), (GClosureNotify) g_object_unref, 0);
+      g_object_ref (dir), (GClosureNotify) (void (*)(void)) g_object_unref, 0);
   gtk_widget_show (mi);
 
   image = gtk_image_new_from_icon_name ("folder-open", GTK_ICON_SIZE_MENU);
@@ -820,7 +820,7 @@ G_GNUC_END_IGNORE_DEPRECATIONS
   gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
   g_signal_connect_data (G_OBJECT (mi), "activate",
       G_CALLBACK (directory_menu_plugin_menu_open_terminal),
-      g_object_ref (dir), (GClosureNotify) g_object_unref, 0);
+      g_object_ref (dir), (GClosureNotify) (void (*)(void)) g_object_unref, 0);
   gtk_widget_show (mi);
 
   image = gtk_image_new_from_icon_name ("utilities-terminal", GTK_ICON_SIZE_MENU);
@@ -969,7 +969,7 @@ G_GNUC_END_IGNORE_DEPRECATIONS
 
               g_signal_connect_data (G_OBJECT (mi), "activate",
                   G_CALLBACK (directory_menu_plugin_menu_launch_desktop_file),
-                  desktopinfo, (GClosureNotify) g_object_unref, 0);
+                  desktopinfo, (GClosureNotify) (void (*)(void)) g_object_unref, 0);
 
               g_object_unref (G_OBJECT (file));
             }
@@ -978,7 +978,7 @@ G_GNUC_END_IGNORE_DEPRECATIONS
             {
               g_signal_connect_data (G_OBJECT (mi), "activate",
                   G_CALLBACK (directory_menu_plugin_menu_launch), file,
-                  (GClosureNotify) g_object_unref, 0);
+                  (GClosureNotify) (void (*)(void)) g_object_unref, 0);
             }
 
           g_object_unref (G_OBJECT (info));
